Stan Math Library: stan/math/prim/scal/err/check_not_nan.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_not_nan.hpp File Reference
`#include <stan/math/prim/scal/meta/length.hpp>`
`#include <stan/math/prim/scal/meta/is_vector_like.hpp>`
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/scal/err/domain_error_vec.hpp>`
`#include <stan/math/prim/scal/fun/value_of_rec.hpp>`
`#include <boost/math/special_functions/fpclassify.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T_y >
bool | stan::math::check_not_nan (const char *function, const char *name, const T_y &y)
| Return `true` if `y` is not `NaN`. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.